#include "rtc_controller.h"
#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>
#include <sys/types.h>
#include <sys/stat.h>
#include <fcntl.h>
#include <string>
#include <string.h>
#include <sys/ioctl.h>

struct linux_rtc_time {
	int tm_sec;
	int tm_min;
	int tm_hour;
	int tm_mday;
	int tm_mon;
	int tm_year;
	int tm_wday;
	int tm_yday;
	int tm_isdst;
};

#ifndef RTC_RD_TIME
#define RTC_RD_TIME		_IOR('p', 0x09, struct linux_rtc_time)
#endif
#ifndef RTC_SET_TIME
#define RTC_SET_TIME	_IOW('p', 0x0a, struct linux_rtc_time)
#endif

int RTCController::rtc_write(struct tm *tm)
{
	struct tm utc_tm;
	time_t local_time;
	int fd, ret, err;

#ifdef DEBUG
	printf("Set RTC: %04d/%02d/%02d %02d:%02d:%02d\n",
		tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday,
		tm->tm_hour, tm->tm_min, tm->tm_sec);
#endif

	tzset();
	local_time = mktime(tm);
	if (local_time == -1)
		return -EINVAL;
	gmtime_r(&local_time, &utc_tm);

	fd = open("/dev/rtc", O_WRONLY);
	if (fd == -1)
		return -errno;
	ret = ioctl(fd, RTC_SET_TIME, &utc_tm);
	err = errno;
	close(fd);
	if (ret == -1)
		return err;

	return 0;
}

int RTCController::rtc_read(struct tm *tm)
{
	struct tm rtc_tm, local_tm;
	time_t utc_time;
	int fd, ret, err;

	memset(&rtc_tm, 0, sizeof(struct tm));
	memset(&local_tm, 0, sizeof(struct tm));

	fd = open("/dev/rtc", O_RDONLY);
	if (fd == -1)
		return -errno;
	ret = ioctl(fd, RTC_RD_TIME, &rtc_tm);
	err = errno;
	close(fd);
	if (ret == -1)
		return err;

	tzset();
	utc_time = timegm(&rtc_tm);
	localtime_r(&utc_time, &local_tm);
	memcpy(tm, &local_tm, sizeof(struct tm));

#ifdef DEBUG
	printf("Get RTC: %04d/%02d/%02d %02d:%02d:%02d\n",
		tm->tm_year + 1900, tm->tm_mon + 1, tm->tm_mday,
		tm->tm_hour, tm->tm_min, tm->tm_sec);
#endif
	return 0;
}

void RTCController::update_sysclk(struct tm *tm)
{
	struct timeval tv;
	memset(&tv, 0, sizeof(struct timeval));

	tv.tv_sec = mktime(tm);
	settimeofday(&tv, NULL);
}
